@@ -6,7 +6,7 @@ use parent qw( Alien::Base );
 use Env qw ( @PATH @LD_LIBRARY_PATH @DYLD_LIBRARY_PATH );
 use Capture::Tiny qw /:all/;
 
-our $VERSION = '1.09';
+our $VERSION = '1.10';
 
 my %also;
 my @alien_bins = (__PACKAGE__->bin_dir);
@@ -61,9 +61,12 @@ sub run_utility {
     push @DYLD_LIBRARY_PATH, $self->dist_dir . '/lib';
 
     if ($self->install_type eq 'share') {
-        my @bin_dirs = $self->bin_dir;
-        my $bin = $bin_dirs[0] // '';
-        $utility = "$bin/$utility";  #  should strip path from $utility first?
+        my $bin = $self->bin_dir;
+        if (defined $bin) {
+            #  should strip path from $utility
+            #  if user specified one?
+            $utility = "$bin/$utility";
+        }
     }
     #  handle spaces in path
     if ($^O =~ /mswin/i) {
